==============================================================================
django-email-hosts -- Support for several SMTP configurations in a single site
==============================================================================

.. image:: https://github.com/feinheit/django-email-hosts/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/feinheit/django-email-hosts/
    :alt: CI Status
